pub fn spawn_printer(rx: UnboundedReceiver<ProgressEvent>) -> JoinHandle<String>Expand description
Spawns the progress printer task. Returns a JoinHandle that resolves to the collected progress string once all senders are dropped.
pub fn spawn_printer(rx: UnboundedReceiver<ProgressEvent>) -> JoinHandle<String>Spawns the progress printer task. Returns a JoinHandle that resolves to the collected progress string once all senders are dropped.