pub struct SkipRecord {
pub span: SpanId,
pub event_seq: EventSeq,
pub marker_kind: MarkerEvalKind,
pub evaluation: MarkerEvalDetail,
pub location: Option<SourceLocation>,
}Expand description
Self-contained pointer used by TestOutcome::Skip to identify which
marker triggered the skip. span is the marker-eval span; event_seq
is the BoolCheck event under it; location is the marker source
{file, line, start, end} denormalised from the span so consumers can
read the verbatim marker line without hopping through spans. The
viewer focuses these at open time and expands ancestors so the markers
tree is unfolded.
Fields
span: SpanIdevent_seq: EventSeqmarker_kind: MarkerEvalKindevaluation: MarkerEvalDetaillocation: Option<SourceLocation>Trait Implementations
Sourceimpl Clone for SkipRecord
impl Clone for SkipRecord
Sourcefn clone(&self) -> SkipRecord
fn clone(&self) -> SkipRecord
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for SkipRecord
impl Debug for SkipRecord
Sourceimpl<'de> Deserialize<'de> for SkipRecord
impl<'de> Deserialize<'de> for SkipRecord
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl Serialize for SkipRecord
impl Serialize for SkipRecord
Sourceimpl TS for SkipRecord
impl TS for SkipRecord
Sourceconst DOCS: Option<&'static str>
const DOCS: Option<&'static str>
TS is derived, docs are
automatically read from your doc comments or #[doc = ".."] attributesSourcetype WithoutGenerics = SkipRecord
type WithoutGenerics = SkipRecord
WithoutGenerics should just be Self.
If the type does have generic parameters, then all generic parameters must be replaced with
a dummy type, e.g ts_rs::Dummy or ().
The only requirement for these dummy types is that EXPORT_TO must be None. Read moreSourcefn decl_concrete() -> String
fn decl_concrete() -> String
TS::decl().
If this type is not generic, then this function is equivalent to TS::decl().Sourcefn decl() -> String
fn decl() -> String
type User = { user_id: number, ... }.
This function will panic if the type has no declaration. Read moreSourcefn inline() -> String
fn inline() -> String
{ user_id: number }.
This function will panic if the type cannot be inlined.Sourcefn inline_flattened() -> String
fn inline_flattened() -> String
This function will panic if the type cannot be flattened.
Sourcefn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
Sourcefn output_path() -> Option<&'static Path>
fn output_path() -> Option<&'static Path>
T should be exported.The returned path does not include the base directory from
TS_RS_EXPORT_DIR. Read moreSourcefn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
Sourcefn dependencies() -> Vec<Dependency>where
Self: 'static,
fn dependencies() -> Vec<Dependency>where
Self: 'static,
Sourcefn export() -> Result<(), ExportError>where
Self: 'static,
fn export() -> Result<(), ExportError>where
Self: 'static,
TS::export_all. Read moreSourcefn export_all() -> Result<(), ExportError>where
Self: 'static,
fn export_all() -> Result<(), ExportError>where
Self: 'static,
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
fn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_to_string() -> Result<String, ExportError>where
Self: 'static,
fn export_to_string() -> Result<String, ExportError>where
Self: 'static,